@@ -1,6 +1,8 @@
 # Generated using https://github.com/RedHatQE/openshift-python-wrapper/blob/main/scripts/resource/README.md
 
-from typing import Any, Dict, List, Optional
+from __future__ import annotations
+
+from typing import Any
 from ocp_resources.resource import Resource
 
 
@@ -20,20 +22,20 @@ class Image(Resource):
 
     def __init__(
         self,
-        additional_trusted_ca: Optional[Dict[str, Any]] = None,
-        allowed_registries_for_import: Optional[List[Any]] = None,
-        external_registry_hostnames: Optional[List[Any]] = None,
-        registry_sources: Optional[Dict[str, Any]] = None,
+        additional_trusted_ca: dict[str, Any] | None = None,
+        allowed_registries_for_import: list[Any] | None = None,
+        external_registry_hostnames: list[Any] | None = None,
+        registry_sources: dict[str, Any] | None = None,
         **kwargs: Any,
     ) -> None:
         """
         Args:
-            additional_trusted_ca (Dict[str, Any]): additionalTrustedCA is a reference to a ConfigMap containing
+            additional_trusted_ca (dict[str, Any]): additionalTrustedCA is a reference to a ConfigMap containing
               additional CAs that should be trusted during imagestream import,
               pod image pull, build image pull, and imageregistry pullthrough.
               The namespace for this config map is openshift-config.
 
-            allowed_registries_for_import (List[Any]): allowedRegistriesForImport limits the container image registries that
+            allowed_registries_for_import (list[Any]): allowedRegistriesForImport limits the container image registries that
               normal users may import images from. Set this list to the
               registries that you trust to contain valid Docker images and that
               you want applications to be able to import from. Users with
@@ -41,13 +43,13 @@ class Image(Resource):
               not affected by this policy - typically only administrators or
               system integrations will have those permissions.
 
-            external_registry_hostnames (List[Any]): externalRegistryHostnames provides the hostnames for the default
+            external_registry_hostnames (list[Any]): externalRegistryHostnames provides the hostnames for the default
               external image registry. The external hostname should be set only
               when the image registry is exposed externally. The first value is
               used in 'publicDockerImageRepository' field in ImageStreams. The
               value must be in "hostname[:port]" format.
 
-            registry_sources (Dict[str, Any]): registrySources contains configuration that determines how the
+            registry_sources (dict[str, Any]): registrySources contains configuration that determines how the
               container runtime should treat individual registries when
               accessing images for builds+pods. (e.g. whether or not to allow
               insecure access).  It does not contain configuration for the
